<?php  if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Shop_model extends Model {

    function Shop_model()
    {
            parent::Model();
    }

    //---------------------------------------------------------------

    /**
     * Function: get_products
     * Description: Fetch the list of products
     * ##############################################################
     * Written: 05/16/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    function get_products($offset = 0, $limit = 25, $where_additional='')
    {
        $this->db->select('*');
        $this->db->from($this->config->item('tbl_products'));
        if ($where_additional){
                $this->db->where($where_additional);
        }
        $this->db->limit($limit, $offset);
        $query = $this->db->get();

        $return = array();
        if ($query->num_rows() > 0){
            foreach($query->result_array() as $key => $product)
            {
                $return[$key] = $product;
                $return[$key]['total_sales'] =  $this->_get_product_sales($product['product_id']);
                $return[$key]['order_link'] = site_url("socket/shop/getP/" . smp_encode($product['product_id']));
                $return[$key]['discussion_link'] =  site_url("socket/discuss/getP/" . smp_encode($product['product_id']));

                //$return[$key]['order_link'] =  "../socket/shop/getP/" . smp_encode($product['product_id']);
                //$return[$key]['discussion_link'] =  "../socket/discuss/getP/" . smp_encode($product['product_id']);
                //$return[$key]['total_refunds'] =  $this->_get_product_refunds($product['product_id']);
                //$return[$key]['total_customers'] =  $this->_get_product_customers($product['product_id']);
            }

            return $return;
        }
        
    }
    //---------------------------------------------------------------

    function _get_product_sales($product_id)
    {
        $this->db->select('SUM(i.price) AS total_sales');
        $this->db->where('i.product_id', $product_id);
        $this->db->from('shop_order_items i');
        $this->db->join('global_transactions t', 'i.order_id = t.transaction_id');
        $this->db->where('t.transaction_status_details', 'completed');


        $this->db->limit(1);

        $query = $this->db->get();

        if ($query->num_rows())
        {
            $row = $query->row_array();
            $total_sales = round($row['total_sales'], 2);
	}
        if ($total_sales){
            return $total_sales;
        }
        else{
            return "0.00";
        }
    }

    /**
     * Function: get_orders
     * Description: Fetch the list of orders
     * ##############################################################
     * Written: 07/23/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    function get_orders($offset = 0, $limit = 25, $where_additional='')
    {
        $this->db->select('*');
        $this->db->from($this->config->item('tbl_transactions'));
        if ($where_additional){
                $this->db->where($where_additional);
        }
        
        $where_additional = "transaction_status_details NOT IN ('subscr_cancel', 'subscr_failed', 'subscr_signup', 'subscr_modify', 'subscr_payment')";
        $this->db->where($where_additional);

        $this->db->limit($limit, $offset);
        $query = $this->db->get();

        $return = array();
        if ($query->num_rows() > 0){
            foreach($query->result_array() as $key => $order)
            {
                $product_id = smp_lookup('product_id', $this->config->item('tbl_order_items'), 'order_id = ' . $order['transaction_id']);
                $order_link = "socket/shop/getP/" . smp_encode($product_id);
                $order_link = site_url($order_link);

                $return[$key] = $order;
                $return[$key]['customer_fname'] =  $this->_get_user_info($order['user_id'], 'first_name');
                $return[$key]['customer_lname'] =  $this->_get_user_info($order['user_id'], 'last_name');
                $return[$key]['customer_email'] =  $this->_get_user_info($order['user_id'], 'email');
                //$return[$key]['product_image']  =  $this->_get_product_image($order['transaction_id']);
                $return[$key]['download_info']  =  $this->_get_download_info($order['transaction_id'], $order['expire_date']);
                $return[$key]['product_id']  =  $product_id;
                $return[$key]['info_link']  =  smp_lookup('info_url', $this->config->item('tbl_products'), 'product_id = ' . $product_id);
                if ($return[$key]['info_link']){
                    $return[$key]['info_link']  =  anchor($return[$key]['info_link'], '[More Information]', 'target=_New');
                }
                $return[$key]['info_link_plain']  =  urlencode(smp_lookup('info_url', $this->config->item('tbl_products'), 'product_id = ' . $product_id));
                $return[$key]['buy_link']   =  anchor($order_link, '[Order Link]', 'target=_New');

                if (smp_lookup('flg_social_discussion', $this->config->item('tbl_products'), 'product_id = ' . $product_id) == YES){
                    $return[$key]['discussion_link']   =  "<img src='". base_url() ."/assets/images/icon-discuss.png'>&nbsp;&nbsp;<a href='". site_url('socket/discuss/getP/' . smp_encode($product_id)) ."' target='_New'><font style='family: tahoma; size:12px; color:#226195; font-weight:bold;'>Leave feedback, ask a question, or simply check out what others are talking about this product</font></a>";
                }
                else {
                    $return[$key]['discussion_link']   =  "";
                }
                $return[$key]['product_image']   =  "<img src='". $this->_get_product_image($order['transaction_id']) ."' border='0' width='150' height='200' align='right'>";
            }

            return $return;
        }

    }

    //---------------------------------------------------------------

    function _get_download_info($order_id, $expire_date)
    {
        $current_date = date("Y-m-d"); // current date
        $date_diff = smp_date_diff("-", $expire_date, $current_date);

        if ($date_diff < 0){
            $product_id = smp_lookup('product_id', $this->config->item('tbl_order_items'), 'order_id = ' . $order_id);
            $order_link = "socket/shop/getP/" . smp_encode($product_id);
            $order_link = site_url($order_link);
            $product_download_page = "Sorry, but the download period for this product has expired. You can renew your access by <a href='". $order_link ."' target='_New'>clicking here</a>.";
        }
        else{
            $product_id = smp_lookup('product_id', $this->config->item('tbl_order_items'), 'order_id = ' . $order_id);
            $product_download_page = smp_lookup('product_download_page', $this->config->item('tbl_products'), 'product_id = ' . $product_id);
            if ($this->session->userdata('role_id') == 2){  // Only if the logged in user is customer
                $product_download_page = smp_hook($this->config->item('hook_shop_download_info'), $product_download_page);
            }
            $product_download_page .= smp_lookup('return_url', $this->config->item('tbl_products'), 'product_id = ' . $product_id);
        }
        return $product_download_page;
    }

    function _get_product_image($order_id)
    {
        $product_id = smp_lookup('product_id', $this->config->item('tbl_order_items'), 'order_id = ' . $order_id);
        $product_image = smp_lookup('image_url', $this->config->item('tbl_products'), 'product_id = ' . $product_id);
        if (!$product_image){
            $product_image = base_url() . "/assets/images/noimage-product.jpg";
        }
        return $product_image;
    }

    /**
     * Function: get_product_gateways
     * Description: Fetch the list of payment gateways linked with product
     * ##############################################################
     * Written: 07/23/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    function get_product_gateways($product_id)
    {
        $this->db->select('gateway_id');
        $this->db->where('product_id', $product_id);

        $options = array();
        $result = array();
        $query = $this->db->get($this->config->item('tbl_product_gateways'));
        foreach($query->result() as $row)
        {
            $result[] = $row->gateway_id;
	}
        return $result;
    }

    //---------------------------------------------------------------

    function _get_user_info($user_id, $column_name)
    {
        $this->db->select($column_name);
        $this->db->where('user_id', $user_id);
        $this->db->limit(1);

        $query = $this->db->get($this->config->item('tbl_users'));

        if ($query->num_rows())
        {
            $row = $query->row_array();
            $column_value = $row[$column_name];
	}
        if ($column_value){
            return $column_value;
        }
        else{
            return "Unknown";
        }
    }

    function process_product($field_array, $table_action = 'Submit', $where_additional = '', $post_action_path = '')
    {
        switch($table_action) {
            case "Submit":
                $this->db->trans_start();
                $data_transaction = array
		(
			'product_name' => $field_array['product_name'],
			'price' => $field_array['price'],
                        'cb_id' => $field_array['cb_id'],
			'image_url' => $field_array['image_url'],
			'description' => $field_array['description'],
			'product_type' => $field_array['product_type'],
			'duration' => $field_array['duration'],
			'duration_type' => $field_array['duration_type'],
                        'currency_code' => $field_array['currency_code'],
			'expire_download' => $field_array['expire_download'],
                        'product_download_page' => $field_array['product_download_page'],
			'autoresponder_unit' => $field_array['autoresponder_unit'],
			'product_license' => $field_array['product_license'],
			'template_id' => $field_array['template_id'],
			'recurring_times' => $field_array['recurring_times'],
			//'site_id' => $field_array['site_id'],
                        'return_url' => $field_array['return_url'],
                        'cancel_url' => $field_array['cancel_url'],
                        //'add_grp' => $field_array['add_grp'],
                        //'remove_grp' => $field_array['remove_grp'],
                        'return_url' => $field_array['return_url'],
                        'cancel_url' => $field_array['cancel_url'],
                        'flg_customer_area' => $field_array['flg_customer_area'],
                        'flg_social_discussion' => $field_array['flg_social_discussion'],
                        'flg_enabled' => $field_array['flg_enabled'],
                        'award_points' => $field_array['award_points'],
                        'require_points' => $field_array['require_points'],
                        'info_url' => $field_array['info_url']
		);
		$this->db->insert($this->config->item('tbl_products'), $data_transaction);

                $product_id = $this->db->insert_id();
                if(isset($field_array['gateways']) && is_array($field_array['gateways'])):
                    foreach ($field_array['gateways'] as &$gateway_id) {
                        $data_gateway = array
                        (
                                'gateway_id' => $gateway_id,
                                'product_id' => $product_id,
                                'gateway_title' => smp_lookup('title', $this->config->item('tbl_gateways'), 'gateway_id = ' . $gateway_id)
                        );
                        $this->db->insert($this->config->item('tbl_product_gateways'), $data_gateway);
                    }
                endif;

                $this->db->trans_complete();
                
                if ($post_action_path){
                    $post_action_path = site_url($post_action_path);
                    header('Location: ' . $post_action_path);
                }
                else{
                    $this->template->set('system_message',  $this->lang->line('message_record_inserted'));
                    return true;
                }
                
            break;

            case "Save":
                $this->db->trans_start();
                $data_transaction = array
		(
			'product_name' => $field_array['product_name'],
			'price' => $field_array['price'],
                        'cb_id' => $field_array['cb_id'],
			'image_url' => $field_array['image_url'],
			'description' => $field_array['description'],
			'product_type' => $field_array['product_type'],
			'duration' => $field_array['duration'],
			'duration_type' => $field_array['duration_type'],
                        'currency_code' => $field_array['currency_code'],
			'expire_download' => $field_array['expire_download'],
                        'product_download_page' => $field_array['product_download_page'],
			'autoresponder_unit' => $field_array['autoresponder_unit'],
			'product_license' => $field_array['product_license'],
			'template_id' => $field_array['template_id'],
			'recurring_times' => $field_array['recurring_times'],
			//'site_id' => $field_array['site_id'],
                        'return_url' => $field_array['return_url'],
                        'cancel_url' => $field_array['cancel_url'],
                        //'add_grp' => $field_array['add_grp'],
                        //'remove_grp' => $field_array['remove_grp'],
                        'return_url' => $field_array['return_url'],
                        'cancel_url' => $field_array['cancel_url'],
                        'flg_customer_area' => $field_array['flg_customer_area'],
                        'flg_social_discussion' => $field_array['flg_social_discussion'],
                        'flg_enabled' => $field_array['flg_enabled'],
                        'award_points' => $field_array['award_points'],
                        'require_points' => $field_array['require_points'],
                        'info_url' => $field_array['info_url']
		);
                $this->db->where($where_additional);
		$this->db->update($this->config->item('tbl_products'), $data_transaction);

                $this->db->where($where_additional);
                $this->db->delete($this->config->item('tbl_product_gateways'));

                if(isset($field_array['gateways']) && is_array($field_array['gateways'])):
                    foreach ($field_array['gateways'] as &$gateway_id) {
                        $data_gateway = array
                        (
                                'gateway_id' => $gateway_id,
                                'product_id' => $field_array['product_id'],
                                'gateway_title' => smp_lookup('title', $this->config->item('tbl_gateways'), 'gateway_id = ' . $gateway_id)
                        );
                        $this->db->insert($this->config->item('tbl_product_gateways'), $data_gateway);
                    }
                endif;

                $this->db->trans_complete();
                $this->template->set('system_message',  $this->lang->line('message_record_updated'));
                return true;

            break;


            case "Delete":
                $this->db->trans_start();
                $this->db->where($where_additional);
                $this->db->delete($this->config->item('tbl_products'));
                $this->db->where($where_additional);
                $this->db->delete($this->config->item('tbl_order_items'));
                $this->db->where($where_additional);
                $this->db->delete($this->config->item('tbl_product_gateways'));
                $this->db->trans_complete();

                if ($post_action_path){
                    $post_action_path = site_url($post_action_path);
                    header('Location: ' . $post_action_path);
                }
                else{
                    $this->template->set('system_message',  $this->lang->line('message_record_deleted'));
                    return true;
                }

            break;      

            case "default":
            break;
        }
        //echo $this->db->last_query();

    }

    function process_order($field_array, $table_action = 'Submit', $where_additional = '', $post_action_path = '')
    {
        $admin_name = smp_lookup('first_name', $this->config->item('tbl_users'), 'user_id = ' . $this->session->userdata('user_id'));
        $admin_email = smp_lookup('email', $this->config->item('tbl_users'), 'user_id = ' . $this->session->userdata('user_id'));

        switch($table_action) {
            case "Submit":

                $this->db->trans_start();
                $product_name = smp_lookup('product_name', $this->config->item('tbl_products'), 'product_id = ' . $field_array['product_id']);
                $product_return_url = smp_lookup('return_url', $this->config->item('tbl_products'), 'product_id = ' . $field_array['product_id']);
                $currency_code = smp_lookup('currency_code', $this->config->item('tbl_products'), 'product_id = ' . $field_array['product_id']);
                $user_email = smp_lookup('email', $this->config->item('tbl_users'), 'user_id = ' . $field_array['user_id']);
                $user_first_name = smp_lookup('first_name', $this->config->item('tbl_users'), 'user_id = ' . $field_array['user_id']);
                $user_last_name = smp_lookup('last_name', $this->config->item('tbl_users'), 'user_id = ' . $field_array['user_id']);
                $user_name = smp_lookup('username', $this->config->item('tbl_users'), 'user_id = ' . $field_array['user_id']);
                $user_password = smp_lookup('password', $this->config->item('tbl_users'), 'user_id = ' . $field_array['user_id']);

                $data_transaction = array
		(
			'transaction_type' => 1,
			'transaction_date' => $field_array['transaction_date'],
			'transaction_category' => 1,
			'transaction_amount' => $field_array['transaction_amount'],
			'currency_code' => $currency_code,
			//'transaction_memo' => $field_array['transaction_memo'],
                        'transaction_notes' => $field_array['transaction_notes'],
			'transaction_title' => $product_name,
			//'member_id' => $field_array['member_id'],
                        'user_id' => $field_array['user_id'],
			'transaction_status_code' => 1,
			'begin_date' => $field_array['begin_date'],
			'expire_date' => $field_array['expire_date'],
			'gateway_id' => $field_array['gateway_id'],
			'transaction_status_details' => $field_array['transaction_status_details'],
                        'channel' => $field_array['channel']
		);
		$this->db->insert($this->config->item('tbl_transactions'), $data_transaction);

                $order_id = $this->db->insert_id();
                $data_order = array
		(
			'order_id' => $order_id,
			'product_id' => $field_array['product_id'],
			'quantity' => 1,
			'price' => $field_array['transaction_amount']
		);
		$this->db->insert($this->config->item('tbl_order_items'), $data_order);
                $this->db->trans_complete();

                if(isset ($field_array['notify_customer'])){
                    $emailTpl = smp_lookup("key_value", $this->config->item('tbl_config'), "key_name = 'TPL_EMAIL_NEW_ORDER_USER'");
                    if ($emailTpl<>"")
                    {
                        $emailTpl = str_replace("{first_name}", $user_first_name, $emailTpl);
                        $emailTpl = str_replace("{last_name}", $user_last_name, $emailTpl);
                        $emailTpl = str_replace("{download_link}", $product_return_url, $emailTpl);
                        $emailTpl = str_replace("{admin_name}", $admin_name . "<br>Email: " . $admin_email, $emailTpl);
                        $emailTpl = str_replace("{item_name}", $product_name, $emailTpl);
                        $emailTpl = str_replace("{username}", $user_name, $emailTpl);
                        $emailTpl = str_replace("{password}", $user_password, $emailTpl);

                        $data['subject'] = '[Your Order]:' . $product_name;
                        $data['message'] = $emailTpl . "<br>(Order Added/Updated by Rep#" . $this->session->userdata('user_id') . ")";
                        $data['from'] = $admin_email;
                        $data['name'] = $admin_name;
                        $data['to'] = $user_email;
                        $data['bcc'] = $admin_email;
                        smp_sendmail($data);
                    }
                }

                if ($post_action_path){
                    $post_action_path = site_url($post_action_path);
                    header('Location: ' . $post_action_path);
                }
                else{
                    $this->template->set('system_message',  $this->lang->line('message_record_inserted'));
                    return true;
                }


            break;

            case "Save":
                if ($field_array['transaction_id'])
                {
                    $this->db->trans_start();
                    $product_name = smp_lookup('product_name', $this->config->item('tbl_products'), 'product_id = ' . $field_array['product_id']);
                    $product_return_url = smp_lookup('return_url', $this->config->item('tbl_products'), 'product_id = ' . $field_array['product_id']);
                    $currency_code = smp_lookup('currency_code', $this->config->item('tbl_products'), 'product_id = ' . $field_array['product_id']);
                    $user_email = smp_lookup('email', $this->config->item('tbl_users'), 'user_id = ' . $field_array['user_id']);
                    $user_first_name = smp_lookup('first_name', $this->config->item('tbl_users'), 'user_id = ' . $field_array['user_id']);
                    $user_last_name = smp_lookup('last_name', $this->config->item('tbl_users'), 'user_id = ' . $field_array['user_id']);
                    $user_name = smp_lookup('username', $this->config->item('tbl_users'), 'user_id = ' . $field_array['user_id']);
                    $user_password = smp_lookup('password', $this->config->item('tbl_users'), 'user_id = ' . $field_array['user_id']);
                    
                    $data_transaction = array
                    (
                            'transaction_type' => 1,
                            'transaction_date' => $field_array['transaction_date'],
                            'transaction_category' => 1,
                            'transaction_amount' => $field_array['transaction_amount'],
                            'currency_code' => $currency_code,
                            //'transaction_memo' => $field_array['transaction_memo'],
                            'transaction_notes' => $field_array['transaction_notes'],
                            'transaction_title' => $product_name,
                            //'member_id' => $field_array['member_id'],
                            'user_id' => $field_array['user_id'],
                            'transaction_status_code' => 1,
                            'begin_date' => $field_array['begin_date'],
                            'expire_date' => $field_array['expire_date'],
                            'gateway_id' => $field_array['gateway_id'],
                            'transaction_status_details' => $field_array['transaction_status_details'],
                            'channel' => $field_array['channel']
                    );
                    $this->db->where('transaction_id', $field_array['transaction_id']);
                    $this->db->update($this->config->item('tbl_transactions'), $data_transaction);

                    $data_order = array
                    (
                            'order_id' => $field_array['transaction_id'],
                            'product_id' => $field_array['product_id'],
                            'quantity' => 1,
                            'price' => $field_array['transaction_amount']
                    );
                    $this->db->where('order_id', $field_array['transaction_id']);
                    $this->db->update($this->config->item('tbl_order_items'), $data_order);
                    $this->db->trans_complete();

                    if(isset ($field_array['notify_customer'])){
                        $emailTpl = smp_lookup("key_value", $this->config->item('tbl_config'), "key_name = 'TPL_EMAIL_NEW_ORDER_USER'");
                        if ($emailTpl<>"")
                        {
                            $emailTpl = str_replace("{first_name}", $user_first_name, $emailTpl);
                            $emailTpl = str_replace("{last_name}", $user_last_name, $emailTpl);
                            $emailTpl = str_replace("{download_link}", $product_return_url, $emailTpl);
                            $emailTpl = str_replace("{admin_name}", $admin_name . "<br>Email: " . $admin_email, $emailTpl);
                            $emailTpl = str_replace("{item_name}", $product_name, $emailTpl);
                            $emailTpl = str_replace("{username}", $user_name, $emailTpl);
                            $emailTpl = str_replace("{password}", $user_password, $emailTpl);

                            $subject = '[Your Order]:' . $product_name;
                            $message = $emailTpl . "<br>(Order Added by Rep#" . $this->session->userdata('user_id') . ")";
                            smp_sendmail($subject, $message, $admin_email, $admin_name, $user_email, '', '', 'html');
                        }
                    }

                    $this->template->set('system_message',  $this->lang->line('message_record_updated'));
                    return true;
                }


            break;

            case "Delete":
                $this->db->trans_start();
                $this->db->where('transaction_id', $field_array['transaction_id']);
                $this->db->delete($this->config->item('tbl_transactions'));
                $this->db->where('order_id', $field_array['transaction_id']);
                $this->db->delete($this->config->item('tbl_order_items'));
                $this->db->trans_complete();
                if ($post_action_path){
                    $post_action_path = site_url($post_action_path);
                    header('Location: ' . $post_action_path);
                }
                else{
                    $this->template->set('system_message',  $this->lang->line('message_record_deleted'));
                    return true;
                }
            break;


            case "default":
            break;
        }
        //echo $this->db->last_query();

    }

    /**
     * Function: set_promo
     * Description: Fetch the list of promotional products
     * ##############################################################
     * Written: 05/16/2010
     * Author: Deep Arora
     * --------------------------------------------------------------
     * Update Log:
     * --------------------------------------------------------------
     * ##############################################################
     * @access public
     * @return void
     */
    function set_promo()
    {
        $promo = "";
        $limit = smp_lookup('key_value', $this->config->item('tbl_config'), 'key_name = \'ADS_NUMBER\'');
        $flg_show_cb_ad = smp_lookup('key_value', $this->config->item('tbl_config'), 'key_name = \'CB_SHOW_AD\'');
        $cb_account = smp_lookup('key_value', $this->config->item('tbl_config'), 'key_name = \'CB_ACCOUNT\'');
        $ad_keywords = smp_lookup('key_value', $this->config->item('tbl_config'), 'key_name = \'ADS_KEYWORDS\'');
        if (!$ad_keywords){
            $ad_keywords = "internet marketing, seo, business";
        }
        
        if (!$limit){
            $limit = 2;
        }
        $this->db->select('*');
        $this->db->from($this->config->item('tbl_products'));
        $this->db->where('flg_customer_area', YES);
        $this->db->order_by('RAND()');
        $this->db->limit($limit);
        $query = $this->db->get();
        //$promo .= "<center><hr noshade size=4 color=#cccccc></center>";
        foreach($query->result() as $row)
        {
            $promo .= "<center><a href='" . $row->info_url . "' target='_New'><img src='" . $row->image_url . "' width='125' height='150' border='0'></a><hr noshade size=4 color=#cccccc><a href='" . $row->info_url . "' target='_New'>Click Here More Info</a><hr noshade size=4 color=#cccccc></center>";
	}

        if($flg_show_cb_ad == "Yes" && $cb_account){
            $promo .= "<script type='text/javascript'>";
            $promo .= "    hopfeed_template='';";
            $promo .= "    hopfeed_align='LEFT';";
            $promo .= "    hopfeed_type='IFRAME';";
            $promo .= "    hopfeed_affiliate_tid='SMP';";
            $promo .= "    hopfeed_affiliate='". $cb_account ."';";
            $promo .= "    hopfeed_fill_slots='true';";
            $promo .= "    hopfeed_height='125';";
            $promo .= "    hopfeed_width='140';";
            $promo .= "    hopfeed_cellpadding='5';";
            $promo .= "    hopfeed_rows='1';";
            $promo .= "    hopfeed_cols='1';";
            $promo .= "    hopfeed_font='Verdana, Arial, Helvetica, Sans Serif';";
            $promo .= "    hopfeed_font_size='8pt';";
            $promo .= "    hopfeed_font_color='000000';";
            $promo .= "    hopfeed_border_color='FFFFFF';";
            $promo .= "    hopfeed_link_font_color='000000';";
            $promo .= "    hopfeed_link_font_hover_color='3300FF';";
            $promo .= "    hopfeed_background_color='cccccc';";
            $promo .= "    hopfeed_keywords='". $ad_keywords ."';";
            $promo .= "    hopfeed_path='http://". $cb_account .".hopfeed.com';";
            $promo .= "    hopfeed_link_target='_blank';";
            $promo .= "</script>";
            $promo .= "<script type='text/javascript' src='http://". $cb_account .".hopfeed.com/script/hopfeed.js'></script>";
        }

        $this->template->set('sb_box_1', $promo);
        $this->template->set('sb_box_title_1', 'Other Similar Products');
    }
    //---------------------------------------------------------------




}

?>
